@@ -89,7 +89,7 @@ class Firewall(object):
         self.__init_vars()
 
     def __repr__(self):
-        return '%s(%r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r)' % \
+        return '%s(%r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r, %r)' % \
             (self.__class__, self.ip4tables_enabled, self.ip6tables_enabled,
              self.ebtables_enabled, self._state, self._panic,
              self._default_zone, self._module_refcount, self._marks,
@@ -185,13 +185,17 @@ class Firewall(object):
             log.debug1("ebtables-restore is not supporting the --noflush "
                        "option, will therefore not be used")
 
-        self.nf_conntrack_helpers = functions.get_nf_conntrack_helpers()
-        if len(self.nf_conntrack_helpers) > 0:
-            log.debug1("Conntrack helpers supported by the kernel:")
-            for key,values in self.nf_conntrack_helpers.items():
-                log.debug1("  %s: %s", key, ", ".join(values))
+        if os.path.exists(config.COMMANDS["modinfo"]):
+            self.nf_conntrack_helpers = functions.get_nf_conntrack_helpers()
+            if len(self.nf_conntrack_helpers) > 0:
+                log.debug1("Conntrack helpers supported by the kernel:")
+                for key,values in self.nf_conntrack_helpers.items():
+                    log.debug1("  %s: %s", key, ", ".join(values))
+            else:
+                log.debug1("No conntrack helpers supported by the kernel.")
         else:
-            log.debug1("No conntrack helpers supported by the kernel.")
+            self.nf_conntrack_helpers = { }
+            log.warning("modinfo command is missing, not able to detect conntrack helpers.")
 
     def _start(self, reload=False, complete_reload=False):
         # initialize firewall
@@ -254,15 +258,15 @@ class Firewall(object):
 
             if self._firewalld_conf.get("AutomaticHelpers"):
                 value = self._firewalld_conf.get("AutomaticHelpers")
-                if value is None:
+                if value is not None:
                     if value.lower() in [ "no", "false" ]:
                         self._automatic_helpers = "no"
-                    if value.lower() in [ "yes", "true" ]:
+                    elif value.lower() in [ "yes", "true" ]:
                         self._automatic_helpers = "yes"
-                else:
-                    self._automatic_helpers = value.lower()
-                log.debug1("AutomaticHelpers is set to '%s'",
-                           self._automatic_helpers)
+                    else:
+                        self._automatic_helpers = value.lower()
+                    log.debug1("AutomaticHelpers is set to '%s'",
+                               self._automatic_helpers)
 
         self.config.set_firewalld_conf(copy.deepcopy(self._firewalld_conf))
 
