@@ -509,13 +509,21 @@ class FirewallDConfigService(slip.dbus.service.Object):
     @dbus_handle_exceptions
     def getModules(self, sender=None): # pylint: disable=W0613
         log.debug1("%s.getModules()", self._log_prefix)
-        return sorted(self.getSettings()[4])
+        return self.getSettings()[4]
 
     @dbus_service_method(config.dbus.DBUS_INTERFACE_CONFIG_SERVICE,
                          in_signature='as')
     @dbus_handle_exceptions
     def setModules(self, modules, sender=None):
         modules = dbus_to_python(modules, list)
+        _modules = [ ]
+        for module in modules:
+            if module.startswith("nf_conntrack_"):
+                module = module.replace("nf_conntrack_", "")
+                if "_" in module:
+                    module = module.replace("_", "-")
+            _modules.append(module)
+        modules = _modules
         log.debug1("%s.setModules('[%s]')", self._log_prefix,
                    ",".join(modules))
         self.parent.accessCheck(sender)
@@ -528,6 +536,10 @@ class FirewallDConfigService(slip.dbus.service.Object):
     @dbus_handle_exceptions
     def addModule(self, module, sender=None):
         module = dbus_to_python(module, str)
+        if module.startswith("nf_conntrack_"):
+            module = module.replace("nf_conntrack_", "")
+            if "_" in module:
+                module = module.replace("_", "-")
         log.debug1("%s.addModule('%s')", self._log_prefix, module)
         self.parent.accessCheck(sender)
         settings = list(self.getSettings())
@@ -541,6 +553,10 @@ class FirewallDConfigService(slip.dbus.service.Object):
     @dbus_handle_exceptions
     def removeModule(self, module, sender=None):
         module = dbus_to_python(module, str)
+        if module.startswith("nf_conntrack_"):
+            module = module.replace("nf_conntrack_", "")
+            if "_" in module:
+                module = module.replace("_", "-")
         log.debug1("%s.removeModule('%s')", self._log_prefix, module)
         self.parent.accessCheck(sender)
         settings = list(self.getSettings())
@@ -554,6 +570,10 @@ class FirewallDConfigService(slip.dbus.service.Object):
     @dbus_handle_exceptions
     def queryModule(self, module, sender=None): # pylint: disable=W0613
         module = dbus_to_python(module, str)
+        if module.startswith("nf_conntrack_"):
+            module = module.replace("nf_conntrack_", "")
+            if "_" in module:
+                module = module.replace("_", "-")
         log.debug1("%s.queryModule('%s')", self._log_prefix, module)
         return module in self.getSettings()[4]
 
